@@ -1,4 +1,4 @@
-{-# LANGUAGE UnicodeSyntax, NoImplicitPrelude, MagicHash, UnboxedTuples #-}
+{-# LANGUAGE NoImplicitPrelude, MagicHash, UnboxedTuples #-}
 
 module Control.Concurrent.Raw ( rawForkIO, rawForkOn ) where
 
@@ -11,11 +11,11 @@ import GHC.Conc      ( ThreadId(ThreadId) )
 -- handler: saves a bit of time when we will be installing our own
 -- exception handler.
 {-# INLINE rawForkIO #-}
-rawForkIO ∷ IO () → IO ThreadId
-rawForkIO action = IO $ \s →
-   case (fork# action s) of (# s1, tid #) → (# s1, ThreadId tid #)
+rawForkIO :: IO () -> IO ThreadId
+rawForkIO action = IO $ \s ->
+   case (fork# action s) of (# s1, tid #) -> (# s1, ThreadId tid #)
 
 {-# INLINE rawForkOn #-}
-rawForkOn ∷ Int → IO () → IO ThreadId
-rawForkOn (I# cpu) action = IO $ \s →
-   case (forkOn# cpu action s) of (# s1, tid #) → (# s1, ThreadId tid #)
+rawForkOn :: Int -> IO () -> IO ThreadId
+rawForkOn (I# cpu) action = IO $ \s ->
+   case (forkOn# cpu action s) of (# s1, tid #) -> (# s1, ThreadId tid #)
