@@ -1,4 +1,4 @@
-{-# LANGUAGE NoImplicitPrelude, UnicodeSyntax, DeriveDataTypeable #-}
+{-# LANGUAGE NoImplicitPrelude, DeriveDataTypeable, ImpredicativeTypes #-}
 
 module Main where
 
@@ -17,7 +17,7 @@ import Control.Monad      ( return, (>>=), replicateM_ )
 import Data.Bool          ( Bool(False, True) )
 import Data.Eq            ( Eq, (==) )
 import Data.Either        ( either )
-import Data.Function      ( ($), id, const, flip )
+import Data.Function      ( (.), ($), id, const, flip )
 import Data.Functor       ( Functor(fmap), (<$>) )
 import Data.Int           ( Int )
 import Data.Maybe         ( Maybe, maybe )
@@ -26,11 +26,7 @@ import Data.Typeable      ( Typeable )
 import System.Timeout     ( timeout )
 import System.IO          ( IO )
 import Text.Show          ( Show )
-
--- from base-unicode-symbols:
-import Data.Eq.Unicode       ( (≡) )
-import Prelude.Unicode       ( (⋅) )
-import Data.Function.Unicode ( (∘) )
+import Prelude            ( (*) )
 
 -- from concurrent-extra:
 import qualified Control.Concurrent.Lock as Lock
@@ -59,10 +55,10 @@ import qualified Control.Concurrent.Thread.Group as ThreadGroup
 -- Tests
 --------------------------------------------------------------------------------
 
-main ∷ IO ()
+main :: IO ()
 main = defaultMain tests
 
-tests ∷ [Test]
+tests :: [Test]
 tests = [ testGroup "Thread" $
           [ testGroup "forkIO" $
             [ testCase "wait"            $ test_wait            Thread.forkIO
@@ -126,22 +122,22 @@ tests = [ testGroup "Thread" $
             , testCase "sync exception"    $ wrapIOWithUnmask test_sync_exception
             , testCase "async exception"   $ wrapIOWithUnmask test_async_exception
 
-            , testCase "group single wait" $ test_group_single_wait $ wrapUnmask ∘ ThreadGroup.forkIOWithUnmask
-            , testCase "group nrOfRunning" $ test_group_nrOfRunning $ wrapUnmask ∘ ThreadGroup.forkIOWithUnmask
+            , testCase "group single wait" $ test_group_single_wait $ wrapUnmask . ThreadGroup.forkIOWithUnmask
+            , testCase "group nrOfRunning" $ test_group_nrOfRunning $ wrapUnmask . ThreadGroup.forkIOWithUnmask
             ]
           , testGroup "forkOnWithUnmask 0" $
             [ testCase "wait"              $ wrapOnWithUnmask test_wait
             , testCase "sync exception"    $ wrapOnWithUnmask test_sync_exception
             , testCase "async exception"   $ wrapOnWithUnmask test_async_exception
 
-            , testCase "group single wait" $ test_group_single_wait $ wrapUnmask ∘ ThreadGroup.forkOnWithUnmask 0
-            , testCase "group nrOfRunning" $ test_group_nrOfRunning $ wrapUnmask ∘ ThreadGroup.forkOnWithUnmask 0
+            , testCase "group single wait" $ test_group_single_wait $ wrapUnmask . ThreadGroup.forkOnWithUnmask 0
+            , testCase "group nrOfRunning" $ test_group_nrOfRunning $ wrapUnmask . ThreadGroup.forkOnWithUnmask 0
             ]
           ]
         ]
 
 -- Exactly 1 moment. Currently equal to 0.005 seconds.
-a_moment ∷ Int
+a_moment :: Int
 a_moment = 5000
 
 
@@ -149,48 +145,48 @@ a_moment = 5000
 -- General properties
 --------------------------------------------------------------------------------
 
-type Fork α = IO α → IO (ThreadId, IO (Result α))
+type Fork a = IO a -> IO (ThreadId, IO (Result a))
 
-wrapUnmask ∷ ((β → α) → t) → α → t
+wrapUnmask :: ((b -> a) -> t) -> a -> t
 wrapUnmask forkWithUnmask = \m -> forkWithUnmask $ const m
 
-test_wait ∷ Fork () → Assertion
-test_wait fork = assert $ fmap isJustTrue $ timeout (10 ⋅ a_moment) $ do
-  r ← newIORef False
-  (_, wait) ← fork $ do
-    threadDelay $ 2 ⋅ a_moment
+test_wait :: Fork () -> Assertion
+test_wait fork = assert $ fmap isJustTrue $ timeout (10 * a_moment) $ do
+  r <- newIORef False
+  (_, wait) <- fork $ do
+    threadDelay $ 2 * a_moment
     writeIORef r True
-  _ ← wait
+  _ <- wait
   readIORef r
 
-test_maskingState ∷ Fork Bool → Assertion
-test_maskingState fork = do (_, wait) ← mask_ $ fork $
+test_maskingState :: Fork Bool -> Assertion
+test_maskingState fork = do (_, wait) <- mask_ $ fork $
                               (MaskedInterruptible ==) <$> getMaskingState
                             wait >>= result >>= assert
 
-test_sync_exception ∷ Fork () → Assertion
+test_sync_exception :: Fork () -> Assertion
 test_sync_exception fork = assert $ do
-  (_, wait) ← fork $ throwIO MyException
+  (_, wait) <- fork $ throwIO MyException
   waitForException MyException wait
 
-waitForException ∷ (Exception e, Eq e) ⇒ e → IO (Result α) → IO Bool
-waitForException e wait = wait <$$> either (justEq e ∘ fromException)
-                                           (const False)
+waitForException :: (Exception e, Eq e) => e -> IO (Result a) -> IO Bool
+waitForException e wait = wait <&> either (justEq e . fromException)
+                                          (const False)
 
-test_async_exception ∷ Fork () → Assertion
+test_async_exception :: Fork () -> Assertion
 test_async_exception fork = assert $ do
-  l ← Lock.newAcquired
-  (tid, wait) ← fork $ Lock.acquire l
+  l <- Lock.newAcquired
+  (tid, wait) <- fork $ Lock.acquire l
   throwTo tid MyException
   waitForException MyException wait
 
 data MyException = MyException deriving (Show, Eq, Typeable)
 instance Exception MyException
 
-test_killThread ∷ Fork () → Assertion
+test_killThread :: Fork () -> Assertion
 test_killThread fork = assert $ do
-  l ← Lock.newAcquired
-  (tid, wait) ← fork $ Lock.acquire l
+  l <- Lock.newAcquired
+  (tid, wait) <- fork $ Lock.acquire l
   killThread tid
   waitForException ThreadKilled wait
 
@@ -199,46 +195,46 @@ test_killThread fork = assert $ do
 -- ThreadGroup
 --------------------------------------------------------------------------------
 
-wrapIO ∷ (Fork α → IO β) → IO β
+wrapIO :: (Fork a -> IO b) -> IO b
 wrapIO = wrap ThreadGroup.forkIO
 
-wrapOS ∷ (Fork α → IO β) → IO β
+wrapOS :: (Fork a -> IO b) -> IO b
 wrapOS = wrap ThreadGroup.forkOS
 
-wrapOn_0 ∷ (Fork α → IO β) → IO β
+wrapOn_0 :: (Fork a -> IO b) -> IO b
 wrapOn_0 = wrap $ ThreadGroup.forkOn 0
 
-wrapIOWithUnmask ∷ (Fork α → IO β) → IO β
+wrapIOWithUnmask :: (Fork a -> IO b) -> IO b
 wrapIOWithUnmask = wrap $ \tg m -> ThreadGroup.forkIOWithUnmask tg $ const m
 
-wrapOnWithUnmask ∷ (Fork α → IO β) → IO β
+wrapOnWithUnmask :: (Fork a -> IO b) -> IO b
 wrapOnWithUnmask = wrap $ \tg m -> ThreadGroup.forkOnWithUnmask 0 tg $ const m
 
-wrap ∷ (ThreadGroup → Fork α) → (Fork α → IO β) → IO β
-wrap doFork test = ThreadGroup.new >>= test ∘ doFork
+wrap :: (ThreadGroup -> Fork a) -> (Fork a -> IO b) -> IO b
+wrap doFork test = ThreadGroup.new >>= test . doFork
 
-test_group_single_wait ∷ (ThreadGroup → Fork ()) → Assertion
-test_group_single_wait doFork = assert $ fmap isJustTrue $ timeout (10 ⋅ a_moment) $ do
-  tg ← ThreadGroup.new
-  r ← newIORef False
-  _ ← doFork tg $ do
-    threadDelay $ 2 ⋅ a_moment
+test_group_single_wait :: (ThreadGroup -> Fork ()) -> Assertion
+test_group_single_wait doFork = assert $ fmap isJustTrue $ timeout (10 * a_moment) $ do
+  tg <- ThreadGroup.new
+  r <- newIORef False
+  _ <- doFork tg $ do
+    threadDelay $ 2 * a_moment
     writeIORef r True
-  _ ← ThreadGroup.wait tg
+  _ <- ThreadGroup.wait tg
   readIORef r
 
-test_group_nrOfRunning ∷ (ThreadGroup → Fork ()) → Assertion
-test_group_nrOfRunning doFork = assert $ fmap isJustTrue $ timeout (10 ⋅ a_moment) $ do
-  tg ← ThreadGroup.new
-  l ← Lock.newAcquired
+test_group_nrOfRunning :: (ThreadGroup -> Fork ()) -> Assertion
+test_group_nrOfRunning doFork = assert $ fmap isJustTrue $ timeout (10 * a_moment) $ do
+  tg <- ThreadGroup.new
+  l <- Lock.newAcquired
   replicateM_ n $ doFork tg $ Lock.acquire l
-  true ← fmap (≡ n) $ (atomically $ ThreadGroup.nrOfRunning tg ∷ IO Int)
+  true <- fmap (== n) $ (atomically $ ThreadGroup.nrOfRunning tg :: IO Int)
   Lock.release l
   return true
     where
       -- Don't set this number too big otherwise forkOS might throw an exception
       -- indicating that too many OS threads have been created:
-      n ∷ Int
+      n :: Int
       n = 100
 
 
@@ -247,13 +243,13 @@ test_group_nrOfRunning doFork = assert $ fmap isJustTrue $ timeout (10 ⋅ a_mom
 --------------------------------------------------------------------------------
 
 -- | Check if the given value equals 'Just' 'True'.
-isJustTrue ∷ Maybe Bool → Bool
+isJustTrue :: Maybe Bool -> Bool
 isJustTrue = maybe False id
 
 -- | Check if the given value in the 'Maybe' equals the given reference value.
-justEq ∷ Eq α ⇒ α → Maybe α → Bool
-justEq = maybe False ∘ (≡)
+justEq :: Eq a => a -> Maybe a -> Bool
+justEq = maybe False . (==)
 
 -- | A flipped '<$>'.
-(<$$>) ∷ Functor f ⇒ f α → (α → β) → f β
-(<$$>) = flip (<$>)
+(<&>) :: (Functor f) => f a -> (a -> b) -> f b
+(<&>) = flip (<$>)
